@@ -29,6 +29,14 @@ def current_date(is_fmt: bool = True, scheme: str = None) -> FmtDate:
     return cur_time
 
 
+def date_parse(obj: str, src_scheme: str = default_fmt_scheme, is_fmt: bool = True, scheme: str = None) -> FmtDate:
+    """文字时间解析成datetime对象，可选再次格式化"""
+    obj_date = datetime.strptime(obj, src_scheme)
+    if is_fmt:
+        obj_date = format_date(obj=obj_date, scheme=scheme)
+    return obj_date
+
+
 def timestamp(ms: bool = False) -> int:
     """当前时间戳生成，默认秒，可选毫秒"""
     cur_time = current_date(is_fmt=False).timestamp()
